@@ -1,7 +1,6 @@
-setClass("gageRR", representation = representation(X = "data.frame", ANOVA = "aov", RedANOVA = "aov", 
-    method = "character", Estimates = "list", Varcomp = "list", Sigma = "numeric", GageName = "character", 
-    GageTolerance = "numeric", DateOfStudy = "character", PersonResponsible = "character", Comments = "character", 
-    b = "factor", a = "factor", y = "numeric", facNames = "character"))
+setClass("gageRR", representation = representation(X = "data.frame", ANOVA = "aov", RedANOVA = "aov", method = "character", Estimates = "list", Varcomp = "list", 
+    Sigma = "numeric", GageName = "character", GageTolerance = "numeric", DateOfStudy = "character", PersonResponsible = "character", Comments = "character", 
+    b = "factor", a = "factor", y = "numeric", facNames = "character", numO = "numeric", numP = "numeric", numM = "numeric"))
 setMethod("show", signature(object = "gageRR"), function(object) {
     print(as.data.frame(object))
 })
@@ -11,7 +10,14 @@ setMethod("[", signature(x = "gageRR", i = "ANY", j = "ANY"), function(x, i, j)
 setMethod("summary", signature(object = "gageRR"), function(object) {
     if (all(is.na(object@X$Measurement))) 
         return(print(as.data.frame(object)))
-    return(gageRR(object))
+    cat("\n")
+    cat(paste("Operators:\t", object@numO, "\tParts:\t", object@numP))
+    cat("\n")
+    cat(paste("Measurements:\t", object@numM, "\tTotal:\t", nrow(object@X)))
+    cat("\n")
+    cat("----------")
+    cat("\n")
+    return(gageRR(object, method = object@method))
 })
 setMethod("response", "gageRR", function(object) {
     out = object@X$Measurement
@@ -48,11 +54,9 @@ setReplaceMethod("sigma", "gageRR", function(x, value) {
     x@Sigma = value
     return(x)
 })
-.aip = function(x.factor, trace.factor, response, fun = mean, type = c("l", "p", "b"), 
-    legend = FALSE, trace.label = deparse(substitute(trace.factor)), fixed = FALSE, xlab = deparse(substitute(x.factor)), 
-    ylab = ylabel, ylim = range(cellNew, na.rm = TRUE), lty = nc:1, col = 1, pch = c(1L:9, 0, letters), 
-    xpd = NULL, leg.bg = par("bg"), leg.bty = "o", xtick = FALSE, xaxt = par("xaxt"), axes = TRUE, 
-    title = "", ...) {
+.aip = function(x.factor, trace.factor, response, fun = mean, type = c("l", "p", "b"), legend = FALSE, trace.label = deparse(substitute(trace.factor)), 
+    fixed = FALSE, xlab = deparse(substitute(x.factor)), ylab = ylabel, ylim = range(cellNew, na.rm = TRUE), lty = nc:1, col = 1, pch = c(1L:9, 0, letters), 
+    xpd = NULL, leg.bg = par("bg"), leg.bty = "o", xtick = FALSE, xaxt = par("xaxt"), axes = TRUE, title = "", ...) {
     ylabel <- paste(deparse(substitute(fun)), "of ", deparse(substitute(response)))
     type <- match.arg(type)
     cellNew <- tapply(response, list(x.factor, trace.factor), fun)
@@ -77,8 +81,7 @@ setReplaceMethod("sigma", "gageRR", function(x, value) {
     xlim <- range(xvals)
     xleg <- xlim[2L] + 0.05 * diff(xlim)
     xlim <- xlim + c(-0.2/nr, if (legend) 0.2 + 0.02 * nch else 0.2/nr) * diff(xlim)
-    matplot(xvals, cellNew, ..., type = type, xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, 
-        axes = axes, xaxt = "n", col = col, lty = lty, pch = pch)
+    matplot(xvals, cellNew, ..., type = type, xlim = xlim, ylim = ylim, xlab = xlab, ylab = ylab, axes = axes, xaxt = "n", col = col, lty = lty, pch = pch)
     if (axes && xaxt != "n") {
         axisInt <- function(x, main, sub, lwd, bg, log, asp, ...) axis(1, x, ...)
         mgp. <- par("mgp")
@@ -96,8 +99,7 @@ setReplaceMethod("sigma", "gageRR", function(x, value) {
         lty, bty = leg.bty, bg = leg.bg, inset = c(-0.2, 0), xpd = TRUE)
     invisible()
 }
-gageRRDesign = function(Operators = 3, Parts = 10, Measurements = 3, method = "crossed", 
-    sigma = 6, randomize = TRUE) {
+gageRRDesign = function(Operators = 3, Parts = 10, Measurements = 3, method = "crossed", sigma = 6, randomize = TRUE) {
     method = method
     opvec = factor()
     partvec = factor()
@@ -124,7 +126,7 @@ gageRRDesign = function(Operators = 3, Parts = 10, Measurements = 3, method = "c
     if (length(unique(opvec)) > 26) 
         stop("To many Operators!")
     if (length(unique(opvec)) < 2) 
-        stop("To few Operators")
+        stop("Not enough Operators")
     if (!is.numeric(Parts) && !is.character(Parts)) 
         stop("Parts needs to be numeric 'Parts = 3' or character 'Parts = c(\"A\",\"B\", \"C\"")
     if (is.numeric(Parts)) 
@@ -146,14 +148,11 @@ gageRRDesign = function(Operators = 3, Parts = 10, Measurements = 3, method = "c
         print(partvec)
         p = rep(sort(rep(partvec, length(opvec))), Measurements)
         o = (rep(opvec, length(Measurement)/length(opvec)))
-        print(p)
-        print(o)
     }
     if (randomize) 
-        outFrame = data.frame(StandardOrder = 1:length(Measurement), RunOrder = sample(1:length(Measurement), 
-            length(Measurement)), Operator = factor(o), Part = factor(p), Measurement)
-    else outFrame = data.frame(StandardOrder = 1:length(Measurement), RunOrder = 1:length(Measurement), 
-        Operator = factor(o), Part = factor(p), Measurement)
+        outFrame = data.frame(StandardOrder = 1:length(Measurement), RunOrder = sample(1:length(Measurement), length(Measurement)), Operator = factor(o), Part = factor(p), 
+            Measurement)
+    else outFrame = data.frame(StandardOrder = 1:length(Measurement), RunOrder = 1:length(Measurement), Operator = factor(o), Part = factor(p), Measurement)
     outFrame = outFrame[order(outFrame$RunOrder), ]
     gageRRObj = new("gageRR")
     gageRRObj@facNames = c(yName, aName, bName, abName)
@@ -168,8 +167,7 @@ gageRRDesign = function(Operators = 3, Parts = 10, Measurements = 3, method = "c
     gageRRObj@X = outFrame
     return(gageRRObj)
 }
-gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL, HM = NULL, 
-    tolerance = NULL, dig = 3, ...) {
+gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL, HM = NULL, tolerance = NULL, dig = 3, ...) {
     yName = names(gdo)[5]
     aName = names(gdo)[3]
     bName = names(gdo)[4]
@@ -192,6 +190,9 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
         numA <- nlevels(a[, drop = T])
         numB <- nlevels(b[, drop = T])
         numMPP <- length(y)/((numB) * numA)
+        gdo@numO = numA
+        gdo@numP = numB
+        gdo@numM = numMPP
         fit = aov(nestedFormula, data = gdo)
         meanSq <- anova(fit)[, 3]
         gdo@ANOVA = fit
@@ -202,8 +203,10 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
         Cerror = MSe
         Cb = (MSab - MSe)/numMPP
         Ca = (MSa - MSab)/(numB * numMPP)
-        if (Ca < 0) 
+        if (Ca <= 0) 
             Ca = 0
+        if (Cb <= 0) 
+            Cb = 0
         Cab = 0
         totalRR = Ca + Cab + Cerror
         repeatability = Cerror
@@ -211,8 +214,7 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
         bTob = Cb
         totalVar = Cb + Ca + Cab + Cerror
         estimates = list(Cb = Cb, Ca = Ca, Cab = Cab, Cerror = Cerror)
-        varcomp = list(totalRR = totalRR, repeatability = repeatability, reproducibility = reproducibility, 
-            bTob = bTob, totalVar = totalVar)
+        varcomp = list(totalRR = totalRR, repeatability = repeatability, reproducibility = reproducibility, bTob = bTob, totalVar = totalVar)
         gdo@Estimates = estimates
         gdo@Varcomp = varcomp
     }
@@ -220,6 +222,9 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
         numA <- nlevels(a[, drop = T])
         numB <- nlevels(b[, drop = T])
         numMPP <- length(a)/(numA * numB)
+        gdo@numO = numA
+        gdo@numP = numB
+        gdo@numM = numMPP
         fit = aov(crossedFormula, data = gdo)
         model <- anova(fit)
         gdo@ANOVA = fit
@@ -273,8 +278,7 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
         bTob = max(0, Cb)
         totalVar = Cb + Ca + Cab + Cerror
         estimates = list(Cb = Cb, Ca = Ca, Cab = Cab, Cerror = Cerror)
-        varcomp = list(totalRR = totalRR, repeatability = repeatability, reproducibility = reproducibility, 
-            a = Ca, a_b = Cab, bTob = bTob, totalVar = totalVar)
+        varcomp = list(totalRR = totalRR, repeatability = repeatability, reproducibility = reproducibility, a = Ca, a_b = Cab, bTob = bTob, totalVar = totalVar)
         gdo@Estimates = estimates
         gdo@Varcomp = varcomp
     }
@@ -296,8 +300,7 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
     Source[Source == "a"] = paste("  ", aName)
     Source[Source == "bTob"] = bTobName
     VarComp = round(as.numeric(gdo@Varcomp[c(1:length(gdo@Varcomp))]), 3)
-    Contribution = round(as.numeric(gdo@Varcomp[c(1:length(gdo@Varcomp))])/as.numeric(gdo@Varcomp[length(gdo@Varcomp)]), 
-        3)
+    Contribution = round(as.numeric(gdo@Varcomp[c(1:length(gdo@Varcomp))])/as.numeric(gdo@Varcomp[length(gdo@Varcomp)]), 3)
     VarComp = t(data.frame(gdo@Varcomp))
     VarCompContrib = VarComp/gdo@Varcomp$totalVar
     Stdev = sqrt(VarComp)
@@ -326,14 +329,12 @@ gageRR = function(gdo, method = "crossed", sigma = 5.15, alpha = 0.25, DM = NULL
     SNRTemp = sqrt(2) * (temp[bTobName, "Stdev"]/temp["totalRR", "Stdev"])
     if (SNRTemp > 1) 
         SNR = SNRTemp
-    cat(paste(" **Number of Distinct Categories (truncated signal-to-noise-ratio) =", floor(SNR), 
-        "\n"))
+    cat(paste(" **Number of Distinct Categories (truncated signal-to-noise-ratio) =", floor(SNR), "\n"))
     cat("\n")
     invisible(gdo)
 }
 setGeneric("plot", function(x, y, ...) standardGeneric("plot"))
-setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col, lwd, 
-    fun = mean, ...) {
+setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col, lwd, fun = mean, ...) {
     horiz = FALSE
     parList = list(...)
     gdo = x
@@ -349,8 +350,7 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
     temp = NULL
     Source = names(gdo@Varcomp)
     VarComp = round(as.numeric(gdo@Varcomp[c(1:length(gdo@Varcomp))]), 3)
-    Contribution = round(as.numeric(gdo@Varcomp[c(1:length(gdo@Varcomp))])/as.numeric(gdo@Varcomp[length(gdo@Varcomp)]), 
-        3)
+    Contribution = round(as.numeric(gdo@Varcomp[c(1:length(gdo@Varcomp))])/as.numeric(gdo@Varcomp[length(gdo@Varcomp)]), 3)
     VarComp = t(data.frame(gdo@Varcomp))
     VarCompContrib = VarComp/gdo@Varcomp$totalVar
     Stdev = sqrt(VarComp)
@@ -390,13 +390,12 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
     else ylab1 = ylab[1]
     argList = list(...)
     redList = argList[names(argList) != "cex"]
-    mybp = do.call(barplot, c(list(t(contribFrame), xlab = xlab1, ylab = ylab1, main = main1, names.arg = rep("", 
-        4), axes = F, beside = T, ylim = c(0, 1.3 * ymax), col = col[1:numBars]), redList))
+    mybp = do.call(barplot, c(list(t(contribFrame), xlab = xlab1, ylab = ylab1, main = main1, names.arg = rep("", 4), axes = F, beside = T, ylim = c(0, 1.3 * 
+        ymax), col = col[1:numBars]), redList))
     axis(1, at = colMeans(mybp), labels = names(as.data.frame(t(contribFrame))), ...)
     axis(2, ...)
     box()
-    legend("topright", names(contribFrame), col = col[1:numBars], pch = c(15, 15), horiz = horiz, 
-        inset = 0.02)
+    legend("topright", names(contribFrame), col = col[1:numBars], pch = c(15, 15), horiz = horiz, inset = 0.02)
     if (gdo@method == "crossed") {
         main2 = NA
         if (missing(main) || is.na(main[2])) 
@@ -413,8 +412,7 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
         boxplot(split(gdo[, yName], gdo[, bName]), xlab = xlab2, ylab = ylab2, main = main2, ...)
         mByPa = split(gdo[, 5], as.numeric(gdo[, 4]))
         lines(sort(as.numeric(gdo[, 4])), lapply(mByPa, median)[sort(as.numeric(gdo[, 4]))], lwd = lwd)
-        points(sort(as.numeric(gdo[, 4])), lapply(mByPa, median)[sort(as.numeric(gdo[, 4]))], lwd = lwd, 
-            pch = 13, cex = 2)
+        points(sort(as.numeric(gdo[, 4])), lapply(mByPa, median)[sort(as.numeric(gdo[, 4]))], lwd = lwd, pch = 13, cex = 2)
         main3 = NA
         if (missing(main) || is.na(main[3])) 
             main3 = paste(yName, "by", aName)
@@ -428,12 +426,10 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
             ylab3 = yName
         else ylab3 = ylab[3]
         colVec = .mapping(gdo[, 3], sort(unique(gdo[, 3])), col[1:length(unique(gdo[, 3]))])
-        boxplot(split(gdo[, yName], gdo[, aName]), col = colVec, xlab = xlab3, ylab = ylab3, main = main3, 
-            ...)
+        boxplot(split(gdo[, yName], gdo[, aName]), col = colVec, xlab = xlab3, ylab = ylab3, main = main3, ...)
         mByOp = split(gdo[, 5], as.numeric(gdo[, 3]))
         lines(sort(as.numeric(factor(names(mByOp)))), lapply(mByOp, mean)[sort(names(mByOp))], lwd = lwd)
-        points(sort(as.numeric(factor(names(mByOp)))), lapply(mByOp, median)[sort(names(mByOp))], 
-            lwd = lwd, pch = 13, cex = 2)
+        points(sort(as.numeric(factor(names(mByOp)))), lapply(mByOp, median)[sort(names(mByOp))], lwd = lwd, pch = 13, cex = 2)
         agg = aggregate(gdo[, yName], list(gdo[, aName], gdo[, bName]), FUN = mean)
         tab = table(agg[, 2])
         sgSize = tab[1]
@@ -447,20 +443,16 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
         values = c(UCL, xm, LCL)
         old.par = par()$mar
         par(mar = c(5.1, 4.1, 4.1, 10.1))
-        plot(agg[, 3], type = "n", axes = FALSE, xlab = aName, ylab = expression(bar(x)), main = expression(paste(bar(x), 
-            " Chart")))
+        plot(agg[, 3], type = "n", axes = FALSE, xlab = aName, ylab = expression(bar(x)), main = expression(paste(bar(x), " Chart")))
         box()
         abline(h = xm, col = 3)
         abline(h = UCL, col = 2)
         abline(h = LCL, col = 2)
         axis(2)
         axis(4, at = c(xm, UCL, LCL), labels = c("", "", ""))
-        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, LCL, paste("LCL =", round(LCL, 2)), adj = 0, 
-            srt = 0, xpd = TRUE)
-        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, UCL, paste("UCL =", round(UCL, 2)), adj = 0, 
-            srt = 0, xpd = TRUE)
-        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, xm, substitute(bar(x) == xm, list(xm = round(xm, 
-            2))), adj = 0, srt = 0, xpd = TRUE)
+        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, LCL, paste("LCL =", round(LCL, 2)), adj = 0, srt = 0, xpd = TRUE)
+        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, UCL, paste("UCL =", round(UCL, 2)), adj = 0, srt = 0, xpd = TRUE)
+        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, xm, substitute(bar(x) == xm, list(xm = round(xm, 2))), adj = 0, srt = 0, xpd = TRUE)
         par(mar = old.par)
         j = 1
         for (i in 1:length(tab)) {
@@ -485,12 +477,10 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
         else ylab4 = ylab[4]
         old.par = par()$mar
         par(mar = c(5.1, 4.1, 4.1, 10.1))
-        .aip(gdo[, 4], gdo[, 3], response = gdo[, 5], xlab = xlab4, ylab = ylab4, main = main4, col = col, 
-            type = "b", title = names(gdo)[3], ...)
+        .aip(gdo[, 4], gdo[, 3], response = gdo[, 5], xlab = xlab4, ylab = ylab4, main = main4, col = col, type = "b", title = names(gdo)[3], ...)
         par(mar = old.par)
         D3 = c(0, 0, 0, 0, 0, 0.076, 0.136, 0.184, 0.223, 0.256, 0.284, 0.308, 0.329, 0.348)
-        D4 = c(0, 3.267, 2.574, 2.282, 2.115, 2.004, 1.924, 1.864, 1.816, 1.777, 1.744, 1.716, 1.692, 
-            1.671, 1.652)
+        D4 = c(0, 3.267, 2.574, 2.282, 2.115, 2.004, 1.924, 1.864, 1.816, 1.777, 1.744, 1.716, 1.692, 1.671, 1.652)
         helpRange = function(x) {
             return(diff(range(x)))
         }
@@ -503,20 +493,16 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
         sgSize = tab[1]
         old.par = par()$mar
         par(mar = c(5.1, 4.1, 4.1, 10.1))
-        plot(agg[, 3], ylim = c(0, max(max(agg[, 3]), UCL)), type = "n", xlab = aName, ylab = "R", 
-            axes = FALSE, main = "R Chart")
+        plot(agg[, 3], ylim = c(0, max(max(agg[, 3]), UCL)), type = "n", xlab = aName, ylab = "R", axes = FALSE, main = "R Chart")
         axis(2)
         axis(4, at = c(Rm, UCL, LCL), labels = c("", "", ""))
         box()
         abline(h = Rm, col = 3)
         abline(h = UCL, col = 2)
         abline(h = LCL, col = 2)
-        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, LCL, paste("LCL =", round(LCL, 2)), adj = 0, 
-            srt = 0, xpd = TRUE)
-        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, UCL, paste("UCL =", round(UCL, 2)), adj = 0, 
-            srt = 0, xpd = TRUE)
-        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, Rm, substitute(bar(R) == Rm, list(Rm = round(Rm, 
-            2))), adj = 0, srt = 0, xpd = TRUE)
+        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, LCL, paste("LCL =", round(LCL, 2)), adj = 0, srt = 0, xpd = TRUE)
+        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, UCL, paste("UCL =", round(UCL, 2)), adj = 0, srt = 0, xpd = TRUE)
+        text(length(agg[, 3]) + length(agg[, 3]) * 0.075, Rm, substitute(bar(R) == Rm, list(Rm = round(Rm, 2))), adj = 0, srt = 0, xpd = TRUE)
         j = 1
         for (i in 1:length(tab)) {
             lines(j:(j + tab[i] - 1), agg[j:(j + tab[i] - 1), 3])
@@ -573,12 +559,10 @@ setMethod("plot", signature(x = "gageRR"), function(x, y, main, xlab, ylab, col,
             ylab3 = yName
         else ylab3 = ylab[3]
         colVec = .mapping(gdo[, 3], sort(unique(gdo[, 3])), col[1:length(unique(gdo[, 3]))])
-        boxplot(split(gdo[, yName], gdo[, aName]), col = colVec, xlab = xlab3, ylab = ylab3, main = main3, 
-            ...)
+        boxplot(split(gdo[, yName], gdo[, aName]), col = colVec, xlab = xlab3, ylab = ylab3, main = main3, ...)
         mByOp = split(gdo[, 5], as.numeric(gdo[, 3]))
         lines(sort(as.numeric(factor(names(mByOp)))), lapply(mByOp, mean)[sort(names(mByOp))], lwd = lwd)
-        points(sort(as.numeric(factor(names(mByOp)))), lapply(mByOp, mean)[sort(names(mByOp))], lwd = lwd, 
-            pch = 13, cex = 2)
+        points(sort(as.numeric(factor(names(mByOp)))), lapply(mByOp, mean)[sort(names(mByOp))], lwd = lwd, pch = 13, cex = 2)
         plot(1, 1, type = "n", axes = FALSE, xlab = NA, ylab = NA, main = NA)
         plot(1, 1, type = "n", axes = FALSE, xlab = NA, ylab = NA, main = NA)
         plot(1, 1, type = "n", axes = FALSE, xlab = NA, ylab = NA, main = NA)
