@@ -1,20 +1,29 @@
-normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, sig.col = c("red1", 
-    "red2", "red3"), main, ylim, xlim, xlab, ylab, pch, col, border = "red", ...) {
+normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, response = NULL, sig.col = c("red1", "red2", "red3"), main, ylim, xlim, xlab, ylab, pch,  ###
+    col, border = "red", ...) {
     DB = FALSE
     require(MASS, quietly = TRUE)
     old.par <- par(no.readonly = TRUE)
     on.exit(par(old.par))
+    fdoName = deparse(substitute(fdo))                                          ###
+    if(is.null(response)==FALSE)                                                ###
+    {                                                                           ###
+     temp=response(fdo)[response]                                               ###
+     response(fdo)=temp                                                         ###
+    }                                                                           ###
     parList = list(...)
     params = list()
     if (length(sig.col) < 3) 
         sig.col = as.vector(matrix(sig.col, nrow = 1, ncol = 3))
-    leg.col = vector()
-    p.col = vector()
-    leg.txt = vector()
+    XLIM=FALSE;YLIM=FALSE                                                       ###
     if (!(class(fdo) == "facDesign")) 
         stop(paste(deparse(substitute(fdo)), "is not an object of class facDesign"))
-    if (missing(main)) 
-        main = paste("Normal plot of", deparse(substitute(fdo)))
+    mainmiss = FALSE                                                            ###
+    if (missing(main))                                                          ###
+        mainmiss = TRUE                                                         ###
+    if (missing(ylim))                                                          ###
+        YLIM=TRUE                                                               ###
+    if (missing(xlim))                                                          ###
+        XLIM=TRUE                                                               ###
     if (missing(xlab)) 
         xlab = "Coefficients"
     if (missing(ylab)) 
@@ -24,6 +33,12 @@ normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, sig.col
     if (missing(col)) 
         col = "black"
     for (j in 1:ncol(response(fdo))) {
+        parList = list(...)                                                     ###
+        params = list()                                                         ###
+        leg.col = vector()                                                      ###
+        p.col = vector()                                                        ###
+        leg.txt = vector()                                                      ###
+        main = paste("Normal plot for", names(response(fdo))[j], "in", fdoName) ###
         if (j > 1) 
             dev.new()
         form = paste("response(fdo)[,", j, "]~")
@@ -37,8 +52,10 @@ normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, sig.col
         lm.1 = lm(as.formula(form), data = as.data.frame(fdo))
         lm.1s = summary(lm.1)
         effect = coef(lm.1s)[row.names(coef(lm.1s)) != "(Intercept)", "t value"]
+        print(effect)
         if (all(is.na(effect))) 
-            stop("effects could not be calculated")
+        effect = 2 * coef(lm.1)[-pmatch("(Intercept)", names(coef(lm.1)))]      ###
+#            stop("effects could not be calculated")                            ###
         sig = summary(lm.1)$coefficients[, "Pr(>|t|)"][-pmatch("(Intercept)", names(coef(lm.1)))]
         df.resid = df.residual(lm.1)
         nc = nrow(centerCube(fdo))
@@ -92,16 +109,18 @@ normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, sig.col
             leg.txt = unique(leg.txt)
             leg.col = unique(leg.col)
         }
+        else                                                                    ###
+         p.col=col                                                              ###
         mid = round(length(tQ)/2)
         last = length(tQ)
         params$p = ppoints(effect)
         estimates = fitdistr(effect, "normal")
         params$mean = estimates$estimate[["mean"]]
-        params$sd = estimates$estimate[["sd"]]
+        params$sd = estimates$estimate[["sd"]]                                                      
         y = do.call(qnorm, params)
-        if (missing(xlim)) 
+        if (XLIM)                                                               ###
             xlim = range(sQ)
-        if (missing(ylim)) 
+        if (YLIM)                                                               ###
             ylim = range(y)
         params = .lfkp(parList, c(formals(plot.default), par()))
         params$x = sQ
@@ -113,10 +132,10 @@ normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, sig.col
         params$ylim = ylim
         params$pch = pch
         params$col = p.col
+
         do.call(plot, params)
         xp = c(qnorm(0.1), qnorm(0.99))
-        yp = c(qnorm(0.1, mean = estimates$estimate[["mean"]], sd = estimates$estimate[["sd"]]), 
-            qnorm(0.99, mean = estimates$estimate[["mean"]], sd = estimates$estimate[["sd"]]))
+        yp = c(qnorm(0.1, mean = estimates$estimate[["mean"]], sd = estimates$estimate[["sd"]]), qnorm(0.99, mean = estimates$estimate[["mean"]], sd = estimates$estimate[["sd"]]))
         slope = (yp[2] - yp[1])/(xp[2] - xp[1])
         int = yp[1] - slope * xp[1]
         abline(a = int, b = slope, col = border)
@@ -125,4 +144,4 @@ normalPlot = function(fdo, threeWay = FALSE, na.last = NA, alpha = 0.05, sig.col
         if (df.resid > 0) 
             legend("topleft", legend = leg.txt, col = leg.col, pch = pch, inset = 0.02)
     }
-} 
+}  
